@@ -4,7 +4,7 @@
 # convertdlg.py, provides the main dialog and GUI interface
 #
 # ConvertAll, a units conversion program
-# Copyright (C) 2015, Douglas W. Bell
+# Copyright (C) 2018, Douglas W. Bell
 #
 # This is free software; you can redistribute it and/or modify it under the
 # terms of the GNU General Public License, either Version 2 or any later
@@ -14,7 +14,12 @@
 
 import sys
 import os.path
-from PyQt4 import QtCore, QtGui
+from PyQt5.QtCore import (QPoint, Qt)
+from PyQt5.QtGui import (QColor, QFont, QPalette)
+from PyQt5.QtWidgets import (QApplication, QCheckBox, QColorDialog, QDialog,
+                             QFrame, QGridLayout, QGroupBox, QHBoxLayout,
+                             QLabel, QLayout, QMenu, QMessageBox, QPushButton,
+                             QSizePolicy, QVBoxLayout, QWidget)
 try:
     from __main__ import __version__, __author__, helpFilePath, iconPath
     from __main__ import lang
@@ -30,20 +35,18 @@ import recentunits
 import unitedit
 import unitlistview
 import numedit
-from modbutton import ModButton
-import finddlg
 import icondict
 import optiondefaults
 import helpview
 import optiondlg
 
 
-class ConvertDlg(QtGui.QWidget):
+class ConvertDlg(QWidget):
     """Main dialog for ConvertAll program.
     """
     unitData = unitdata.UnitData()
     def __init__(self, parent=None):
-        QtGui.QWidget.__init__(self, parent)
+        super().__init__(parent)
         self.setWindowTitle('ConvertAll')
         modPath = os.path.abspath(sys.path[0])
         if modPath.endswith('.zip'):  # for py2exe
@@ -53,20 +56,18 @@ class ConvertDlg(QtGui.QWidget):
         self.icons = icondict.IconDict()
         self.icons.addIconPath([path for path in iconPathList if path])
         try:
-            QtGui.QApplication.setWindowIcon(self.icons['convertall_med'])
+            QApplication.setWindowIcon(self.icons['convertall_med'])
         except KeyError:
             pass
         self.helpView = None
-        self.findDlg = None
         self.option = Option('convertall', 20)
         self.option.loadAll(optiondefaults.defaultList)
         self.recentUnits = recentunits.RecentUnits(self.option)
         try:
             num = ConvertDlg.unitData.readData()
         except unitdata.UnitDataError as text:
-            QtGui.QMessageBox.warning(self, 'ConvertAll',
-                                      _('Error in unit data - {0}').
-                                      format(text))
+            QMessageBox.warning(self, 'ConvertAll',
+                                _('Error in unit data - {0}').  format(text))
             sys.exit(1)
         try:
             print(_('{0} units loaded').format(num))
@@ -74,119 +75,155 @@ class ConvertDlg(QtGui.QWidget):
             print('{0} units loaded'.format(num))
         self.fromGroup = UnitGroup(ConvertDlg.unitData, self.option)
         self.toGroup = UnitGroup(ConvertDlg.unitData, self.option)
-        self.origPal = QtGui.QApplication.palette()
+        self.origPal = QApplication.palette()
         self.updateColors()
+        self.unitButtons = []
         self.textButtons = []
-        self.recentButtons = []
 
-        topLayout = QtGui.QHBoxLayout(self)    # divide main, buttons
-        mainLayout = QtGui.QVBoxLayout()
+        topLayout = QHBoxLayout(self)    # divide main, buttons
+        mainLayout = QVBoxLayout()
+        mainLayout.setSpacing(8)
         topLayout.addLayout(mainLayout)
-        unitLayout = QtGui.QHBoxLayout()       # unit selection
+        unitLayout = QGridLayout()       # unit selection
+        unitLayout.setVerticalSpacing(3)
+        unitLayout.setHorizontalSpacing(20)
         mainLayout.addLayout(unitLayout)
 
-        fromBox = QtGui.QGroupBox(_('From Unit'))
-        unitLayout.addWidget(fromBox)
-        fromLayout = QtGui.QVBoxLayout(fromBox)
-        fromLayout.setSpacing(3)
+        fromLabel = QLabel(_('From Unit'))
+        unitLayout.addWidget(fromLabel, 0, 0)
         self.fromUnitEdit = unitedit.UnitEdit(self.fromGroup)
-        fromLayout.addWidget(self.fromUnitEdit)
+        unitLayout.addWidget(self.fromUnitEdit, 1, 0)
         self.fromUnitEdit.setFocus()
-        self.fromUnitListView = unitlistview.UnitListView(self.fromGroup, 0)
-        fromLayout.addWidget(self.fromUnitListView)
-        self.fromUnitEdit.currentChanged.connect(self.fromUnitListView.
-                                                 updateSelection)
-        self.fromUnitListView.unitChanged.connect(self.fromUnitEdit.unitUpdate)
-        self.fromUnitListView.setFocusProxy(self.fromUnitEdit)
-        self.addButtons(self.fromGroup, self.fromUnitListView, fromLayout)
 
-        toBox = QtGui.QGroupBox(_('To Unit'))
-        unitLayout.addWidget(toBox)
-        toLayout = QtGui.QVBoxLayout(toBox)
-        toLayout.setSpacing(3)
+        toLabel = QLabel(_('To Unit'))
+        unitLayout.addWidget(toLabel, 0, 1)
         self.toUnitEdit = unitedit.UnitEdit(self.toGroup)
-        toLayout.addWidget(self.toUnitEdit)
-        self.toUnitListView = unitlistview.UnitListView(self.toGroup, 1)
-        toLayout.addWidget(self.toUnitListView)
-        self.toUnitEdit.currentChanged.connect(self.toUnitListView.
-                                               updateSelection)
-        self.toUnitListView.unitChanged.connect(self.toUnitEdit.unitUpdate)
-        self.toUnitListView.setFocusProxy(self.toUnitEdit)
-        self.addButtons(self.toGroup, self.toUnitListView, toLayout)
+        unitLayout.addWidget(self.toUnitEdit, 1, 1)
+        self.fromUnitEdit.gotFocus.connect(self.toUnitEdit.setInactive)
+        self.toUnitEdit.gotFocus.connect(self.fromUnitEdit.setInactive)
+
+        vertButtonLayout = QVBoxLayout()
+        vertButtonLayout.setSpacing(2)
+        mainLayout.addLayout(vertButtonLayout)
+
+        self.unitListView = unitlistview.UnitListView(ConvertDlg.unitData)
+        mainLayout.addWidget(self.unitListView)
+        self.fromUnitEdit.currentChanged.connect(self.unitListView.
+                                                 updateFiltering)
+        self.toUnitEdit.currentChanged.connect(self.unitListView.
+                                               updateFiltering)
+        self.fromUnitEdit.keyPressed.connect(self.unitListView.handleKeyPress)
+        self.toUnitEdit.keyPressed.connect(self.unitListView.handleKeyPress)
+        self.unitListView.unitChanged.connect(self.fromUnitEdit.unitUpdate)
+        self.unitListView.unitChanged.connect(self.toUnitEdit.unitUpdate)
+        self.unitListView.haveCurrentUnit.connect(self.enableButtons)
+        self.unitListView.setFocusPolicy(Qt.NoFocus)
+
+        textButtonLayout = QHBoxLayout()
+        textButtonLayout.setSpacing(6)
+        vertButtonLayout.addLayout(textButtonLayout)
+        textButtonLayout.addStretch(1)
+        self.textButtons.append(QPushButton('{0} (^2)'.format(_('Square'))))
+        self.textButtons.append(QPushButton('{0} (^3)'.format(_('Cube'))))
+        self.textButtons.append(QPushButton('{0} (*)'.format(_('Multiply'))))
+        self.textButtons.append(QPushButton('{0} (/)'.format(_('Divide'))))
+        for button in self.textButtons:
+            button.setSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
+            button.setFocusPolicy(Qt.NoFocus)
+            textButtonLayout.addWidget(button)
+            button.clicked.connect(self.unitListView.addUnitText)
+        textButtonLayout.addStretch(1)
+
+        unitButtonLayout = QHBoxLayout()
+        unitButtonLayout.setSpacing(6)
+        vertButtonLayout.addLayout(unitButtonLayout)
+        unitButtonLayout.addStretch(1)
+        self.clearButton = QPushButton(_('Clear Unit'))
+        self.clearButton.clicked.connect(self.unitListView.clearUnitText)
+        self.recentButton = QPushButton(_('Recent Unit'))
+        self.recentButton.clicked.connect(self.recentMenu)
+        self.filterButton = QPushButton(_('Filter List'))
+        self.filterButton.clicked.connect(self.filterMenu)
+        self.unitButtons = [self.clearButton, self.recentButton,
+                            self.filterButton]
+        for button in self.unitButtons:
+            button.setSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
+            button.setFocusPolicy(Qt.NoFocus)
+            unitButtonLayout.addWidget(button)
+        unitButtonLayout.addStretch(1)
         self.showHideButtons()
 
-        numberLayout = QtGui.QHBoxLayout()
+        numberLayout = QGridLayout()
+        numberLayout.setVerticalSpacing(3)
         mainLayout.addLayout(numberLayout)
-        statusLabel = QtGui.QLabel(_('Set units'))
-        statusLabel.setFrameStyle(QtGui.QFrame.Panel | QtGui.QFrame.Sunken)
+        statusLabel = QLabel(_('Set units'))
+        statusLabel.setFrameStyle(QFrame.Panel | QFrame.Sunken)
         mainLayout.addWidget(statusLabel)
 
-        fromNumBox = QtGui.QGroupBox(_('No Unit Set'))
-        numberLayout.addWidget(fromNumBox)
-        fromNumLayout = QtGui.QVBoxLayout(fromNumBox)
+        fromNumLabel = QLabel(_('No Unit Set'))
+        numberLayout.addWidget(fromNumLabel, 0, 0)
         self.fromNumEdit = numedit.NumEdit(self.fromGroup, self.toGroup,
-                                           fromNumBox, statusLabel,
+                                           fromNumLabel, statusLabel,
                                            self.recentUnits, True)
-        fromNumLayout.addWidget(self.fromNumEdit)
+        numberLayout.addWidget(self.fromNumEdit, 1, 0)
         self.fromUnitEdit.unitChanged.connect(self.fromNumEdit.unitUpdate)
+        self.fromNumEdit.gotFocus.connect(self.fromUnitEdit.setInactive)
+        self.fromNumEdit.gotFocus.connect(self.toUnitEdit.setInactive)
+        self.fromNumEdit.gotFocus.connect(self.unitListView.resetFiltering)
         self.fromNumEdit.setEnabled(False)
-        equalsLabel = QtGui.QLabel(' = ')
-        equalsLabel.setFont(QtGui.QFont(self.font().family(), 30))
-        numberLayout.addWidget(equalsLabel)
+        equalsLabel = QLabel(' = ')
+        equalsLabel.setFont(QFont(self.font().family(), 20))
+        numberLayout.addWidget(equalsLabel, 0, 1, 2, 1)
 
-        toNumBox = QtGui.QGroupBox(_('No Unit Set'))
-        numberLayout.addWidget(toNumBox)
-        toNumLayout = QtGui.QVBoxLayout(toNumBox)
+        toNumLabel = QLabel(_('No Unit Set'))
+        numberLayout.addWidget(toNumLabel, 0, 3)
         self.toNumEdit = numedit.NumEdit(self.toGroup, self.fromGroup,
-                                         toNumBox, statusLabel,
+                                         toNumLabel, statusLabel,
                                          self.recentUnits, False)
-        toNumLayout.addWidget(self.toNumEdit)
+        numberLayout.addWidget(self.toNumEdit, 1, 3)
         self.toUnitEdit.unitChanged.connect(self.toNumEdit.unitUpdate)
+        self.toNumEdit.gotFocus.connect(self.fromUnitEdit.setInactive)
+        self.toNumEdit.gotFocus.connect(self.toUnitEdit.setInactive)
+        self.toNumEdit.gotFocus.connect(self.unitListView.resetFiltering)
         self.toNumEdit.setEnabled(False)
         self.fromNumEdit.convertNum.connect(self.toNumEdit.setNum)
         self.toNumEdit.convertNum.connect(self.fromNumEdit.setNum)
-        self.fromNumEdit.convertNum.connect(self.setRecentAvail)
-        self.toNumEdit.convertNum.connect(self.setRecentAvail)
         self.fromNumEdit.convertRqd.connect(self.toNumEdit.convert)
         self.toNumEdit.convertRqd.connect(self.fromNumEdit.convert)
 
-        buttonLayout = QtGui.QVBoxLayout()     # major buttons
+        buttonLayout = QVBoxLayout()     # major buttons
         topLayout.addLayout(buttonLayout)
-        closeButton = QtGui.QPushButton(_('&Close'))
+        closeButton = QPushButton(_('&Close'))
         buttonLayout.addWidget(closeButton)
-        closeButton.setFocusPolicy(QtCore.Qt.NoFocus)
+        closeButton.setFocusPolicy(Qt.NoFocus)
         closeButton.clicked.connect(self.close)
-        finderButton = QtGui.QPushButton(_('&Unit Finder...'))
-        buttonLayout.addWidget(finderButton)
-        finderButton.setFocusPolicy(QtCore.Qt.NoFocus)
-        finderButton.clicked.connect(self.showFinder)
-        optionsButton = QtGui.QPushButton(_('&Options...'))
+        optionsButton = QPushButton(_('&Options...'))
         buttonLayout.addWidget(optionsButton)
-        optionsButton.setFocusPolicy(QtCore.Qt.NoFocus)
+        optionsButton.setFocusPolicy(Qt.NoFocus)
         optionsButton.clicked.connect(self.changeOptions)
-        helpButton = QtGui.QPushButton(_('&Help...'))
+        helpButton = QPushButton(_('&Help...'))
         buttonLayout.addWidget(helpButton)
-        helpButton.setFocusPolicy(QtCore.Qt.NoFocus)
+        helpButton.setFocusPolicy(Qt.NoFocus)
         helpButton.clicked.connect(self.help)
-        aboutButton = QtGui.QPushButton(_('&About...'))
+        aboutButton = QPushButton(_('&About...'))
         buttonLayout.addWidget(aboutButton)
-        aboutButton.setFocusPolicy(QtCore.Qt.NoFocus)
+        aboutButton.setFocusPolicy(Qt.NoFocus)
         aboutButton.clicked.connect(self.about)
         buttonLayout.addStretch()
 
-        xSize = self.option.intData('MainDlgXSize', 0, 10000)
-        ySize = self.option.intData('MainDlgYSize', 0, 10000)
-        if xSize and ySize:
-            self.resize(xSize, ySize)
-        self.move(self.option.intData('MainDlgXPos', 0, 10000),
-                  self.option.intData('MainDlgYPos', 0, 10000))
+        if self.option.boolData('RemenberDlgPos'):
+            xSize = self.option.intData('MainDlgXSize', 0, 10000)
+            ySize = self.option.intData('MainDlgYSize', 0, 10000)
+            if xSize and ySize:
+                self.resize(xSize, ySize)
+            self.move(self.option.intData('MainDlgXPos', 0, 10000),
+                      self.option.intData('MainDlgYPos', 0, 10000))
         if self.option.boolData('LoadLastUnit') and len(self.recentUnits) > 1:
             self.fromGroup.update(self.recentUnits[0])
             self.fromUnitEdit.unitUpdate()
-            self.fromUnitListView.updateSelection()
             self.toGroup.update(self.recentUnits[1])
             self.toUnitEdit.unitUpdate()
-            self.toUnitListView.updateSelection()
+            self.unitListView.updateFiltering()
             self.fromNumEdit.setFocus()
             self.fromNumEdit.selectAll()
         if self.option.boolData('ShowStartupTip'):
@@ -194,64 +231,70 @@ class ConvertDlg(QtGui.QWidget):
             tipDialog = TipDialog(self.option, self)
             tipDialog.exec_()
 
-    def addButtons(self, unitGroup, listView, upperLayout):
-        """Add buttons to unit selector.
-        """
-        buttonLayout = QtGui.QHBoxLayout()
-        upperLayout.addLayout(buttonLayout)
-        buttons = []
-        buttons.append(ModButton(unitGroup.addOper, 1, 'X'))
-        buttons.append(ModButton(unitGroup.addOper, 0, '/'))
-        buttons.append(ModButton(unitGroup.changeExp, 2, '^2'))
-        buttons.append(ModButton(unitGroup.changeExp, 3, '^3'))
-        for button in buttons:
-            buttonLayout.addWidget(button)
-        listView.buttonList = buttons[:]
-        buttons.append(ModButton(unitGroup.clearUnit, None, _('Clear Unit')))
-        extraLayout = QtGui.QHBoxLayout()
-        upperLayout.addLayout(extraLayout)
-        extraLayout.addWidget(buttons[-1])
-        for but in buttons:
-            but.stateChg.connect(listView.relayChange)
-            but.setEnabled(False)
-            self.textButtons.append(but)
-        buttons[-1].setEnabled(True)
-        recentButton = QtGui.QPushButton(_('Recent Unit'))
-        recentButton.setFocusPolicy(QtCore.Qt.NoFocus)
-        recentButton.unitGroup = unitGroup
-        recentButton.clicked.connect(self.recentMenu)
-        extraLayout.addWidget(recentButton)
-        self.textButtons.append(recentButton)
-        self.recentButtons.append(recentButton)
-        self.setRecentAvail()
-
     def recentMenu(self):
         """Show a menu with recently used units.
         """
         button = self.sender()
-        menu = QtGui.QMenu()
+        menu = QMenu()
         for unit in self.recentUnits:
             action = menu.addAction(unit)
-            action.unitGroup = button.unitGroup
-            menu.triggered.connect(self.insertRecent)
-        menu.exec_(button.mapToGlobal(QtCore.QPoint(0, 0)))
-
-    def setRecentAvail(self):
-        """Enable or disable recent unit button.
-        """
-        for button in self.recentButtons:
-            button.setEnabled(len(self.recentUnits))
+        menu.triggered.connect(self.insertRecent)
+        menu.exec_(button.mapToGlobal(QPoint(0, 0)))
 
     def insertRecent(self, action):
         """Insert the recent unit from the given action.
         """
-        action.unitGroup.update(action.text())
-        if action.unitGroup is self.fromGroup:
-            self.fromUnitEdit.unitUpdate()
-            self.fromUnitListView.updateSelection()
-        else:
-            self.toUnitEdit.unitUpdate()
-            self.toUnitListView.updateSelection()
+        editor = (self.fromUnitEdit if self.fromUnitEdit.activeEditor else
+                  self.toUnitEdit)
+        editor.unitGroup.update(action.text())
+        editor.unitUpdate()
+        self.unitListView.updateFiltering()
+
+    def filterMenu(self):
+        """Show a menu with unit types for filtering or clear filter if set.
+        """
+        if self.unitListView.typeFilter:  # clear filter
+            self.unitListView.typeFilter = ''
+            self.unitListView.updateFiltering()
+            self.filterButton.setText(_('Filter List'))
+        else:  # show filter menu
+            button = self.sender()
+            menu = QMenu()
+            for unitType in ConvertDlg.unitData.typeList:
+                action = menu.addAction(unitType)
+            menu.triggered.connect(self.startTypeFilter)
+            menu.exec_(button.mapToGlobal(QPoint(0, 0)))
+
+    def startTypeFilter(self, action):
+        """Start type filter based on the given action.
+        """
+        self.unitListView.typeFilter = action.text()
+        self.unitListView.updateFiltering()
+        self.filterButton.setText(_('Clear Filter'))
+
+    def enableButtons(self, editActive, hasUnit):
+        """Enable text editing buttons if have a current unit.
+        """
+        for button in self.textButtons:
+            button.setEnabled(hasUnit)
+        self.clearButton.setEnabled(editActive)
+        self.recentButton.setEnabled(editActive and len(self.recentUnits))
+
+    def showHideButtons(self):
+        """Show or hide text modify buttons.
+        """
+        textButtonsVisible = self.option.boolData('ShowOpButtons')
+        unitButtonsVisible = self.option.boolData('ShowUnitButtons')
+        for button in self.textButtons:
+            if textButtonsVisible:
+                button.show()
+            else:
+                button.hide()
+        for button in self.unitButtons:
+            if unitButtonsVisible:
+                button.show()
+            else:
+                button.hide()
 
     def updateColors(self):
         """Adjust the colors to the current option settings.
@@ -259,19 +302,10 @@ class ConvertDlg(QtGui.QWidget):
         if self.option.boolData('UseDefaultColors'):
             pal = self.origPal
         else:
-            pal = QtGui.QPalette()
-            pal.setColor(QtGui.QPalette.Base,
-                         self.getOptionColor('Background'))
-            pal.setColor(QtGui.QPalette.Text,
-                         self.getOptionColor('Foreground'))
-        QtGui.QApplication.setPalette(pal)
-
-    def showFinder(self):
-        """Show dialog for searhing and filtering units.
-        """
-        if not self.findDlg:
-            self.findDlg = finddlg.FindDlg(self)
-        self.findDlg.show()
+            pal = QPalette()
+            pal.setColor(QPalette.Base, self.getOptionColor('Background'))
+            pal.setColor(QPalette.Text, self.getOptionColor('Foreground'))
+        QApplication.setPalette(pal)
 
     def changeOptions(self):
         """Show dialog for option changes.
@@ -294,15 +328,19 @@ class ConvertDlg(QtGui.QWidget):
                                 _('Load last units at startup'))
         dlg.startGroupBox(_('User Interface'))
         optiondlg.OptionDlgBool(dlg, 'ShowOpButtons',
-                                _('Show operator buttons'))
+                                _('Show operator buttons (1st row)'))
+        optiondlg.OptionDlgBool(dlg, 'ShowUnitButtons',
+                                _('Show unit buttons (2nd row)'))
         optiondlg.OptionDlgBool(dlg, 'ShowStartupTip',
                                 _('Show tip at startup'))
+        optiondlg.OptionDlgBool(dlg, 'RemenberDlgPos',
+                                _('Remember window position'))
         dlg.startGroupBox(_('Colors'))
         optiondlg.OptionDlgBool(dlg, 'UseDefaultColors',
                                 _('Use default system colors'))
         optiondlg.OptionDlgPush(dlg, _('Set background color'), self.backColor)
         optiondlg.OptionDlgPush(dlg, _('Set text color'), self.textColor)
-        if dlg.exec_() == QtGui.QDialog.Accepted:
+        if dlg.exec_() == QDialog.Accepted:
             self.option.writeChanges()
             self.recentUnits.updateQuantity()
             self.updateColors()
@@ -316,9 +354,9 @@ class ConvertDlg(QtGui.QWidget):
     def getOptionColor(self, rootName):
         """Return a color from option storage.
         """
-        return QtGui.QColor(self.option.intData(rootName + 'R', 0, 255),
-                            self.option.intData(rootName + 'G', 0, 255),
-                            self.option.intData(rootName + 'B', 0, 255))
+        return QColor(self.option.intData(rootName + 'R', 0, 255),
+                      self.option.intData(rootName + 'G', 0, 255),
+                      self.option.intData(rootName + 'B', 0, 255))
 
     def setOptionColor(self, rootName, color):
         """Store given color in options.
@@ -331,7 +369,7 @@ class ConvertDlg(QtGui.QWidget):
         """Allow user to set control background color.
         """
         background = self.getOptionColor('Background')
-        newColor = QtGui.QColorDialog.getColor(background, self)
+        newColor = QColorDialog.getColor(background, self)
         if newColor.isValid() and newColor != background:
             self.setOptionColor('Background', newColor)
 
@@ -339,20 +377,10 @@ class ConvertDlg(QtGui.QWidget):
         """Allow user to set control text color.
         """
         foreground = self.getOptionColor('Foreground')
-        newColor = QtGui.QColorDialog.getColor(foreground, self)
+        newColor = QColorDialog.getColor(foreground, self)
         if newColor.isValid() and newColor != foreground:
             self.setOptionColor('Foreground', newColor)
 
-    def showHideButtons(self):
-        """Show or hide text modify buttons.
-        """
-        visible = self.option.boolData('ShowOpButtons')
-        for button in self.textButtons:
-            if visible:
-                button.show()
-            else:
-                button.hide()
-
     def findHelpFile(self):
         """Return the path to the help file.
         """
@@ -378,8 +406,8 @@ class ConvertDlg(QtGui.QWidget):
         if not self.helpView:
             path = self.findHelpFile()
             if not path:
-                QtGui.QMessageBox.warning(self, 'ConvertAll',
-                                          _('Read Me file not found'))
+                QMessageBox.warning(self, 'ConvertAll',
+                                    _('Read Me file not found'))
                 return
             self.helpView = helpview.HelpView(path,
                                               _('ConvertAll README File'),
@@ -389,44 +417,40 @@ class ConvertDlg(QtGui.QWidget):
     def about(self):
         """Show about info.
         """
-        QtGui.QMessageBox.about(self, 'ConvertAll',
-                                _('ConvertAll Version {0}\nby {1}').
-                                format(__version__, __author__))
+        QMessageBox.about(self, 'ConvertAll',
+                          _('ConvertAll Version {0}\nby {1}').
+                          format(__version__, __author__))
 
     def closeEvent(self, event):
         """Save window data on close.
         """
-        self.option.changeData('MainDlgXSize', self.width(), True)
-        self.option.changeData('MainDlgYSize', self.height(), True)
-        self.option.changeData('MainDlgXPos', self.x(), True)
-        self.option.changeData('MainDlgYPos', self.y(), True)
-        if self.findDlg:
-            self.option.changeData('FinderXSize', self.findDlg.width(), True)
-            self.option.changeData('FinderYSize', self.findDlg.height(), True)
-            self.option.changeData('FinderXPos', self.findDlg.x(), True)
-            self.option.changeData('FinderYPos', self.findDlg.y(), True)
+        if self.option.boolData('RemenberDlgPos'):
+            self.option.changeData('MainDlgXSize', self.width(), True)
+            self.option.changeData('MainDlgYSize', self.height(), True)
+            self.option.changeData('MainDlgXPos', self.x(), True)
+            self.option.changeData('MainDlgYPos', self.y(), True)
         self.recentUnits.writeList()
         self.option.writeChanges()
         event.accept()
 
 
-class TipDialog(QtGui.QDialog):
+class TipDialog(QDialog):
     """Show a static usage tip at startup by default.
     """
     def __init__(self, option, parent=None):
-        QtGui.QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.option = option
-        self.setWindowFlags(QtCore.Qt.Dialog | QtCore.Qt.WindowTitleHint |
-                            QtCore.Qt.WindowSystemMenuHint)
+        self.setWindowFlags(Qt.Dialog | Qt.WindowTitleHint |
+                            Qt.WindowSystemMenuHint)
         self.setWindowTitle(_('Convertall - Tip'))
-        topLayout = QtGui.QVBoxLayout(self)
+        topLayout = QVBoxLayout(self)
         self.setLayout(topLayout)
 
-        box = QtGui.QGroupBox(_('Combining Units'))
+        box = QGroupBox(_('Combining Units'))
         topLayout.addWidget(box)
-        boxLayout = QtGui.QVBoxLayout(box)
-        label = QtGui.QLabel(self)
-        label.setTextFormat(QtCore.Qt.RichText)
+        boxLayout = QVBoxLayout(box)
+        label = QLabel(self)
+        label.setTextFormat(Qt.RichText)
         label.setText(_('<p>ConvertAll\'s strength is the ability to combine '
                         'units:</p>'
                         '<ul><li>Enter "m/s" to get meters per second</li>'
@@ -437,14 +461,14 @@ class TipDialog(QtGui.QDialog):
                         '</ul>'))
         boxLayout.addWidget(label)
 
-        ctrlLayout = QtGui.QHBoxLayout()
+        ctrlLayout = QHBoxLayout()
         topLayout.addLayout(ctrlLayout)
-        self.showCheck = QtGui.QCheckBox(_('Show this tip at startup'), self)
+        self.showCheck = QCheckBox(_('Show this tip at startup'), self)
         self.showCheck.setChecked(True)
         ctrlLayout.addWidget(self.showCheck)
 
         ctrlLayout.addStretch()
-        okButton = QtGui.QPushButton(_('&OK'), self)
+        okButton = QPushButton(_('&OK'), self)
         ctrlLayout.addWidget(okButton)
         okButton.clicked.connect(self.accept)
 
@@ -453,4 +477,4 @@ class TipDialog(QtGui.QDialog):
         """
         if not self.showCheck.isChecked():
             self.option.changeData('ShowStartupTip', 'no', True)
-        QtGui.QDialog.accept(self)
+        super().accept()
